@@ -1,4 +1,4 @@
-/* $Id: jpilot.c,v 1.177 2008/12/15 13:24:04 judd Exp $ */
+/* $Id: jpilot.c,v 1.179 2009/02/14 17:32:31 rousseau Exp $ */
 
 /*******************************************************************************
  * jpilot.c
@@ -106,7 +106,6 @@ static GtkWidget *button_locked,
 GtkCheckMenuItem *menu_hide_privates, 
                  *menu_show_privates, 
                  *menu_mask_privates;
-int t_fmt_ampm = TRUE;
 
 int pipe_from_child, pipe_to_parent;
 int pipe_from_parent, pipe_to_child;
@@ -221,6 +220,12 @@ void cb_plugin_gui(GtkWidget *widget, int number)
    call_plugin_gui(number, 0);
 }
 
+/* Redraws plugin GUI after structure changing event such as category editing */
+void plugin_gui_refresh(int unique_id)
+{
+   call_plugin_gui(glob_app, unique_id); 
+}
+
 void call_plugin_help(int number)
 {
    struct plugin_s *plugin;
@@ -1519,11 +1524,6 @@ int main(int argc, char *argv[])
 
    pref_init();
 
-   /* Determine whether locale supports am/pm time formats */
-#  ifdef HAVE_LANGINFO_H
-      t_fmt_ampm = strcmp(nl_langinfo(T_FMT_AMPM), "");
-#  endif
-
    /* read jpilot.rc file for preferences */
    pref_read_rc_file();
 
