@@ -1,4 +1,4 @@
-/* $Id: memo_gui.c,v 1.128 2008/10/30 15:07:12 rousseau Exp $ */
+/* $Id: memo_gui.c,v 1.130 2009/01/19 22:17:02 rikster5 Exp $ */
 
 /*******************************************************************************
  * memo_gui.c
@@ -160,9 +160,7 @@ static void set_new_button_to(int new_state)
    record_changed=new_state;
 }
 
-static void
-cb_record_changed(GtkWidget *widget,
-		  gpointer   data)
+static void cb_record_changed(GtkWidget *widget, gpointer data)
 {
    jp_logf(JP_LOG_DEBUG, "cb_record_changed\n");
    if (record_changed==CLEAR_FLAG) {
@@ -671,15 +669,40 @@ int memo_export(GtkWidget *window)
  * End Export Code
  */
 
-static int find_sorted_cat(int cat)
+/* Find position of category in sorted category array 
+ * via its assigned category number */
+static int find_sort_cat_pos(int cat)
 {
    int i;
-   for (i=0; i< NUM_MEMO_CAT_ITEMS; i++) {
+
+   for (i=0; i<NUM_MEMO_CAT_ITEMS; i++) {
       if (sort_l[i].cat_num==cat) {
  	 return i;
       }
    }
-   return EXIT_FAILURE;
+
+   return -1;
+}
+
+/* Find a category's position in the category menu.
+ * This is equal to the category number except for the Unfiled category.
+ * The Unfiled category is always in the last position which changes as
+ * the number of categories changes */
+static int find_menu_cat_pos(int cat)
+{
+   int i;
+
+   if (cat != NUM_MEMO_CAT_ITEMS-1) {
+      return cat;
+   } else { /* Unfiled category */
+      /* Count how many category entries are filled */
+      for (i=0; i<NUM_MEMO_CAT_ITEMS; i++) {
+         if (!sort_l[i].Pcat[0]) {
+            return i;
+         }
+      }
+      return 0;
+   }
 }
 
 void cb_delete_memo(GtkWidget *widget,
@@ -837,8 +860,32 @@ static void cb_category(GtkWidget *item, int selection)
    int b;
 
    if ((GTK_CHECK_MENU_ITEM(item))->active) {
-      b=dialog_save_changed_record(pane, record_changed);
-      if (b==DIALOG_SAID_2) {
+      if (memo_category == selection) { return; }
+
+      b=dialog_save_changed_record_with_cancel(pane, record_changed);
+      if (b==DIALOG_SAID_1) { /* Cancel */
+         int index, index2;
+
+         if (memo_category==CATEGORY_ALL) {
+            index  = 0;
+            index2 = 0;
+         } else {
+            index  = find_sort_cat_pos(memo_category);
+            index2 = find_menu_cat_pos(index) + 1;
+            index += 1;
+         }
+
+         if (index<0) {
+            jp_logf(JP_LOG_WARN, _("Category is not legal\n"));
+         } else {
+            gtk_check_menu_item_set_active
+              (GTK_CHECK_MENU_ITEM(memo_cat_menu_item1[index]), TRUE);
+            gtk_option_menu_set_history(GTK_OPTION_MENU(category_menu1), index2);
+         }
+
+	 return;
+      }
+      if (b==DIALOG_SAID_3) { /* Save */
 	 cb_add_new_record(NULL, GINT_TO_POINTER(record_changed));
       }
 
@@ -849,7 +896,6 @@ static void cb_category(GtkWidget *item, int selection)
       }
       clist_row_selected = 0;
       jp_logf(JP_LOG_DEBUG, "cb_category() cat=%d\n", memo_category);
-      memo_clear_details();
       memo_update_clist(clist, category_menu1, &glob_memo_list, memo_category, TRUE);
       jp_logf(JP_LOG_DEBUG, "Leaving cb_category()\n");
    }
@@ -874,13 +920,14 @@ static int memo_clear_details()
    } else {
       new_cat = memo_category;
    }
-   sorted_position = find_sorted_cat(new_cat);
+   sorted_position = find_sort_cat_pos(new_cat);
    if (sorted_position<0) {
       jp_logf(JP_LOG_WARN, _("Category is not legal\n"));
    } else {
       gtk_check_menu_item_set_active
 	(GTK_CHECK_MENU_ITEM(memo_cat_menu_item2[sorted_position]), TRUE);
-      gtk_option_menu_set_history(GTK_OPTION_MENU(category_menu2), sorted_position);
+      gtk_option_menu_set_history(GTK_OPTION_MENU(category_menu2), 
+                                  find_menu_cat_pos(sorted_position));
    }
 
    set_new_button_to(CLEAR_FLAG);
@@ -1018,20 +1065,33 @@ static void cb_clist_selection(GtkWidget      *clist,
 {
    struct Memo *memo;
    MyMemo *mmemo;
-   int i, index, count, b;
-   int sorted_position;
+   int b;
+   int index, sorted_position;
    unsigned int unique_id = 0;
 
    if ((record_changed==MODIFY_FLAG) || (record_changed==NEW_FLAG)) {
+      if (clist_row_selected == row) { return; } 
+
       mmemo = gtk_clist_get_row_data(GTK_CLIST(clist), row);
       if (mmemo!=NULL) {
 	 unique_id = mmemo->unique_id;
       }
 
-      b=dialog_save_changed_record(pane, record_changed);
-      if (b==DIALOG_SAID_2) {
+      b=dialog_save_changed_record_with_cancel(pane, record_changed);
+      if (b==DIALOG_SAID_1) { /* Cancel */
+         if (clist_row_selected >=0)
+         {
+            clist_select_row(GTK_CLIST(clist), clist_row_selected, 0);
+         } else {
+            clist_row_selected = 0;
+            clist_select_row(GTK_CLIST(clist), 0, 0);
+         }
+         return;
+      }
+      if (b==DIALOG_SAID_3) { /* Save */
 	 cb_add_new_record(NULL, GINT_TO_POINTER(record_changed));
       }
+
       set_new_button_to(CLEAR_FLAG);
 
       if (unique_id)
@@ -1067,19 +1127,12 @@ static void cb_clist_selection(GtkWidget      *clist,
    memo=&(mmemo->memo);
 
    index = mmemo->attrib & 0x0F;
-   sorted_position = find_sorted_cat(index);
+   sorted_position = find_sort_cat_pos(index);
    if (memo_cat_menu_item2[sorted_position]==NULL) {
       /* Illegal category */
       jp_logf(JP_LOG_DEBUG, "Category is not legal\n");
       index = sorted_position = 0;
    }
-   /* We need to count how many items down in the list this is */
-   for (i=sorted_position, count=0; i>=0; i--) {
-      if (memo_cat_menu_item2[i]) {
-	 count++;
-      }
-   }
-   count--;
 
    if (sorted_position<0) {
       jp_logf(JP_LOG_WARN, _("Category is not legal\n"));
@@ -1087,7 +1140,8 @@ static void cb_clist_selection(GtkWidget      *clist,
       gtk_check_menu_item_set_active
 	(GTK_CHECK_MENU_ITEM(memo_cat_menu_item2[sorted_position]), TRUE);
    }
-   gtk_option_menu_set_history(GTK_OPTION_MENU(category_menu2), count);
+   gtk_option_menu_set_history(GTK_OPTION_MENU(category_menu2), 
+                               find_menu_cat_pos(sorted_position));
 
    gtk_text_buffer_set_text(GTK_TEXT_BUFFER(memo_text_buffer), memo->text, -1);
 
@@ -1331,8 +1385,9 @@ int memo_cycle_cat()
    if (memo_category == CATEGORY_ALL) {
       new_cat = -1;
    } else {
-      new_cat = find_sorted_cat(memo_category);
+      new_cat = find_sort_cat_pos(memo_category);
    }
+
    for (i=0; i<NUM_MEMO_CAT_ITEMS; i++) {
       new_cat++;
       if (new_cat >= NUM_MEMO_CAT_ITEMS) {
@@ -1344,6 +1399,7 @@ int memo_cycle_cat()
 	 break;
       }
    }
+
    clist_row_selected = 0;
 
    return EXIT_SUCCESS;
@@ -1351,31 +1407,26 @@ int memo_cycle_cat()
 
 int memo_refresh()
 {
-   int index;
+   int index, index2;
 
    if (glob_find_id) {
       memo_category = CATEGORY_ALL;
    }
    if (memo_category==CATEGORY_ALL) {
-      index=0;
+      index  = 0;
+      index2 = 0; 
    } else {
-      index=find_sorted_cat(memo_category)+1;
+      index  = find_sort_cat_pos(memo_category);
+      index2 = find_menu_cat_pos(index) + 1;
+      index += 1;
    }
    memo_update_clist(clist, category_menu1, &glob_memo_list, memo_category, TRUE);
    if (index<0) {
       jp_logf(JP_LOG_WARN, _("Category is not legal\n"));
    } else {
-      int i, index2 = 0;
-      for (i=0; i<NUM_MEMO_CAT_ITEMS; i++)
-      {
-	 if (memo_cat_menu_item1[i] && (memo_cat_menu_item1[i] != memo_cat_menu_item1[index]))
-	    index2++;
-	 if (memo_cat_menu_item1[i] == memo_cat_menu_item1[index])
-	    break;
-      }
-      gtk_option_menu_set_history(GTK_OPTION_MENU(category_menu1), index2);
       gtk_check_menu_item_set_active
 	(GTK_CHECK_MENU_ITEM(memo_cat_menu_item1[index]), TRUE);
+      gtk_option_menu_set_history(GTK_OPTION_MENU(category_menu1), index2);
    }
    memo_find();
    return EXIT_SUCCESS;
