@@ -1,4 +1,4 @@
-/* $Id: monthview_gui.c,v 1.41 2008/05/03 02:58:16 judd Exp $ */
+/* $Id: monthview_gui.c,v 1.46 2008/06/19 04:12:07 rikster5 Exp $ */
 
 /*******************************************************************************
  * monthview_gui.c
@@ -20,56 +20,49 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  ******************************************************************************/
 
+/********************************* Includes ***********************************/
 #include "config.h"
-#include "i18n.h"
-#include <gtk/gtk.h>
-#include <string.h>
-#include <ctype.h>
 #include <stdlib.h>
+#include <string.h>
+#include <gtk/gtk.h>
+#include <pi-datebook.h>
+
 #include "utils.h"
-#include "print.h"
+#include "i18n.h"
 #include "prefs.h"
 #include "log.h"
 #include "datebook.h"
-#include <pi-datebook.h>
-#include "config.h"
+#include "print.h"
 
+/******************************* Global vars **********************************/
 extern int datebook_category;
 extern int glob_app;
 
-static GtkWidget *window=NULL;
-static GtkWidget *glob_month_vbox;
-static GtkWidget *glob_month_labels[37];
-#ifdef ENABLE_GTK2
-static GObject   *glob_month_text_buffers[37];
-static GtkWidget *glob_month_text_views[37];
-static GObject   *big_text_buffer;
-#else
-static GtkWidget *glob_month_texts[37];
-static GtkWidget *big_text;
-#endif
-static GtkWidget *glob_month_month_label;
+GtkWidget *monthview_window=NULL;
+static GtkWidget *month_day_label[37];
+static GtkWidget *month_day[37];
+static GObject   *month_day_buffer[37];
+static GObject   *all_appts_buffer;
+static GtkWidget *month_month_label;
 static GtkWidget *glob_last_hbox_row;
 static int glob_offset;
 static struct tm glob_month_date;
 
+/****************************** Prototypes ************************************/
 int display_months_appts(struct tm *glob_month_date, GtkWidget **glob_month_texts);
 void hide_show_month_boxes();
 
+/****************************** Main Code *************************************/
 static gboolean cb_destroy(GtkWidget *widget)
 {
    int n;
    GString *gstr;
    GtkWidget *text;
 
-   window = NULL;
+   monthview_window = NULL;
 
    for (n=0; n<37; n++) {
-#ifdef ENABLE_GTK2
-      text = glob_month_text_views[n];
-#else
-      text = glob_month_texts[n];
-#endif
+      text = month_day[n];
       gstr = gtk_object_get_data(GTK_OBJECT(text), "gstr");
       if (gstr) {
 	 g_string_free(gstr, TRUE);
@@ -79,15 +72,15 @@ static gboolean cb_destroy(GtkWidget *widget)
    return FALSE;
 }
 
-static void cb_quit(GtkWidget *widget, gpointer data)
+void cb_monthview_quit(GtkWidget *widget, gpointer data)
 {
    int w, h;
 
-   gdk_window_get_size(window->window, &w, &h);
+   gdk_window_get_size(monthview_window->window, &w, &h);
    set_pref(PREF_MONTHVIEW_WIDTH, w, NULL, FALSE);
    set_pref(PREF_MONTHVIEW_HEIGHT, h, NULL, FALSE);
 
-   gtk_widget_destroy(window);
+   gtk_widget_destroy(monthview_window);
 }
 
 static void cb_month_move(GtkWidget *widget, gpointer data)
@@ -101,23 +94,15 @@ static void cb_month_move(GtkWidget *widget, gpointer data)
       add_days_to_date(&glob_month_date, 30);
    }
    hide_show_month_boxes();
-#ifdef ENABLE_GTK2
-   display_months_appts(&glob_month_date, glob_month_text_views);
-#else
-   display_months_appts(&glob_month_date, glob_month_texts);
-#endif
+   display_months_appts(&glob_month_date, month_day);
 }
 
-/*----------------------------------------------------------------------
- * cb_month_print	This is where month printing is kicked off from
- *----------------------------------------------------------------------*/
-
 static void cb_month_print(GtkWidget *widget, gpointer data)
 {
    long paper_size;
 
    jp_logf(JP_LOG_DEBUG, "cb_month_print called\n");
-   if (print_gui(window, DATEBOOK, 3, 0x04) == DIALOG_SAID_PRINT) {
+   if (print_gui(monthview_window, DATEBOOK, 3, 0x04) == DIALOG_SAID_PRINT) {
       get_pref(PREF_PAPER_SIZE, &paper_size, NULL);
       if (paper_size==1) {
 	 print_months_appts(&glob_month_date, PAPER_A4);
@@ -127,14 +112,10 @@ static void cb_month_print(GtkWidget *widget, gpointer data)
    }
 }
 
-/*----------------------------------------------------------------------*/
-
 static void cb_enter_notify(GtkWidget *widget, GdkEvent *event, gpointer data)
 {
    static int prev_day=-1;
-#ifdef ENABLE_GTK2
    GtkWidget *textview;
-#endif 
    GString *gstr;
    
    if (prev_day==GPOINTER_TO_INT(data)+1-glob_offset) {
@@ -142,27 +123,16 @@ static void cb_enter_notify(GtkWidget *widget, GdkEvent *event, gpointer data)
    }
    prev_day = GPOINTER_TO_INT(data)+1-glob_offset;
 
-#ifdef ENABLE_GTK2
    textview = gtk_bin_get_child(GTK_BIN(widget));
    gstr = gtk_object_get_data(GTK_OBJECT(textview), "gstr");
    if (gstr) {
-      gtk_text_buffer_set_text(GTK_TEXT_BUFFER(big_text_buffer), gstr->str, -1);
+      gtk_text_buffer_set_text(GTK_TEXT_BUFFER(all_appts_buffer), gstr->str, -1);
    } else {
-      gtk_text_buffer_set_text(GTK_TEXT_BUFFER(big_text_buffer), "", -1);
+      gtk_text_buffer_set_text(GTK_TEXT_BUFFER(all_appts_buffer), "", -1);
    }
-#else
-   gstr = gtk_object_get_data(GTK_OBJECT(widget), "gstr");
-   gtk_text_set_point(GTK_TEXT(big_text),
-		      gtk_text_get_length(GTK_TEXT(big_text)));
-   gtk_text_backward_delete(GTK_TEXT(big_text),
-			    gtk_text_get_length(GTK_TEXT(big_text)));
-   if (gstr) {
-      gtk_text_insert(GTK_TEXT(big_text), NULL, NULL, NULL, gstr->str, -1);
-   }
-#endif
 }
 
-/* Called when a day is clicked on the month view */
+/* Called when a day is clicked on in the month view */
 static void cb_enter_selected_day(GtkWidget *widget, 
                                   GdkEvent  *event, 
 				  gpointer   data)
@@ -190,9 +160,7 @@ void hide_show_month_boxes()
    char str[40];
    int d;
    GtkWidget *text;
-#ifdef ENABLE_GTK2
    char *markup_str;
-#endif
 
    /* Determine today for highlighting */
    now_today = get_highlighted_today(&glob_month_date);
@@ -212,14 +180,9 @@ void hide_show_month_boxes()
    }
 
    for (n=0; n<37; n++, d++) {
-#ifdef ENABLE_GTK2
-      text = glob_month_text_views[n];
-#else
-      text = glob_month_texts[n];
-#endif
+      text = month_day[n];
       g_snprintf(str, sizeof(str), "%d", d);
 
-#ifdef ENABLE_GTK2
       if (d == now_today)
       {
 	 markup_str = g_markup_printf_escaped("<b>%s</b>", str);
@@ -228,32 +191,25 @@ void hide_show_month_boxes()
 	 markup_str = g_markup_printf_escaped("%s", str);
          gtk_widget_set_name(text, "");
       }
-      gtk_label_set_markup(GTK_LABEL(glob_month_labels[n]), markup_str);
+      gtk_label_set_markup(GTK_LABEL(month_day_label[n]), markup_str);
       g_free(markup_str);
-#else
-      if (d == now_today)
-      {
-	 g_snprintf(str, sizeof(str), "%s%s", str, _(" (TODAY)"));
-      }
-      gtk_label_set_text(GTK_LABEL(glob_month_labels[n]), str);
-#endif
 
       if (n<7) {
 	 if (d>0) {
 	    gtk_widget_show(GTK_WIDGET(text));
-	    gtk_widget_show(GTK_WIDGET(glob_month_labels[n]));
+	    gtk_widget_show(GTK_WIDGET(month_day_label[n]));
 	 } else {
 	    gtk_widget_hide(GTK_WIDGET(text));
-	    gtk_widget_hide(GTK_WIDGET(glob_month_labels[n]));
+	    gtk_widget_hide(GTK_WIDGET(month_day_label[n]));
 	 }
       }
       if (n>27) {
 	 if (d<=ndim) {
 	    gtk_widget_show(GTK_WIDGET(text));
-	    gtk_widget_show(GTK_WIDGET(glob_month_labels[n]));
+	    gtk_widget_show(GTK_WIDGET(month_day_label[n]));
 	 } else {
 	    gtk_widget_hide(GTK_WIDGET(text));
-	    gtk_widget_hide(GTK_WIDGET(glob_month_labels[n]));
+	    gtk_widget_hide(GTK_WIDGET(month_day_label[n]));
 	 }
       }
    }
@@ -265,9 +221,7 @@ void create_month_boxes_texts(GtkWidget *month_vbox)
    GtkWidget *hbox_row;
    GtkWidget *vbox;
    GtkWidget *text;
-#ifdef ENABLE_GTK2
    GtkWidget *event_box;
-#endif
    char str[80];
 
    n=0;
@@ -276,23 +230,18 @@ void create_month_boxes_texts(GtkWidget *month_vbox)
       gtk_box_pack_start(GTK_BOX(month_vbox), hbox_row, TRUE, TRUE, 0);
       for (j=0; j<7; j++) {
 	 vbox = gtk_vbox_new(FALSE, 0);
-#ifdef ENABLE_GTK2
 	 gtk_box_pack_start(GTK_BOX(hbox_row), vbox, TRUE, TRUE, 2);
-#else
-	 gtk_box_pack_start(GTK_BOX(hbox_row), vbox, TRUE, TRUE, 0);
-#endif
 	 n=i*7+j;
 	 if (n<37) {
 	    sprintf(str, "%d", n + 1);
 	    /* Day of month labels */
-	    glob_month_labels[n] = gtk_label_new(str);
-	    gtk_misc_set_alignment(GTK_MISC(glob_month_labels[n]), 0.0, 0.5);
-	    gtk_box_pack_start(GTK_BOX(vbox), glob_month_labels[n], FALSE, FALSE, 0);
+	    month_day_label[n] = gtk_label_new(str);
+	    gtk_misc_set_alignment(GTK_MISC(month_day_label[n]), 0.0, 0.5);
+	    gtk_box_pack_start(GTK_BOX(vbox), month_day_label[n], FALSE, FALSE, 0);
 
-#ifdef ENABLE_GTK2
 	    /* text variable only used to save some typing */
-	    text = glob_month_text_views[n] = gtk_text_view_new();
-	    glob_month_text_buffers[n] =
+	    text = month_day[n] = gtk_text_view_new();
+	    month_day_buffer[n] =
 	      G_OBJECT(gtk_text_view_get_buffer(GTK_TEXT_VIEW(text)));
 	    gtk_widget_set_usize(GTK_WIDGET(text), 10, 10);
 	    gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(text), FALSE);
@@ -313,36 +262,18 @@ void create_month_boxes_texts(GtkWidget *month_vbox)
 
 	    gtk_box_pack_start(GTK_BOX(vbox), event_box, TRUE, TRUE, 0);
 
-#else
-	    text = glob_month_texts[n] = gtk_text_new(NULL, NULL);
-	    gtk_widget_set_usize(GTK_WIDGET(glob_month_texts[n]), 10, 10);
-	    gtk_text_set_word_wrap(GTK_TEXT(glob_month_texts[n]), FALSE);
-	    gtk_signal_connect(GTK_OBJECT(glob_month_texts[n]), "enter_notify_event",
-			       GTK_SIGNAL_FUNC(cb_enter_notify), GINT_TO_POINTER(n));
-	    gtk_signal_connect(GTK_OBJECT(text), "button_release_event",
-			       GTK_SIGNAL_FUNC(cb_enter_selected_day),
-			       GINT_TO_POINTER(n));
-
-	    gtk_box_pack_start(GTK_BOX(vbox), text, TRUE, TRUE, 0);
-#endif
 	 }
       }
    }
    glob_last_hbox_row = hbox_row;
 
-#ifdef ENABLE_GTK2
    text = gtk_text_view_new();
-   big_text_buffer = G_OBJECT(gtk_text_view_get_buffer(GTK_TEXT_VIEW(text)));
+   all_appts_buffer = G_OBJECT(gtk_text_view_get_buffer(GTK_TEXT_VIEW(text)));
    gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(text), FALSE);
    gtk_text_view_set_editable(GTK_TEXT_VIEW(text), FALSE);
    gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(text), GTK_WRAP_WORD);
    gtk_widget_set_usize(GTK_WIDGET(text), 10, 10);
    gtk_box_pack_start(GTK_BOX(month_vbox), text, TRUE, TRUE, 4);
-#else
-   big_text = gtk_text_new(NULL, NULL);
-   gtk_widget_set_usize(GTK_WIDGET(big_text), 10, 10);
-   gtk_box_pack_start(GTK_BOX(month_vbox), big_text, TRUE, TRUE, 0);
-#endif
 }
 
 int display_months_appts(struct tm *date_in, GtkWidget **day_texts)
@@ -351,9 +282,7 @@ int display_months_appts(struct tm *date_in, GtkWidget **day_texts)
    AppointmentList *temp_al;
    struct tm date;
    GtkWidget **texts;
-#ifdef ENABLE_GTK2
    GObject   **text_buffers;
-#endif
    char desc[100];
    char datef[20];
    char str[80];
@@ -373,19 +302,13 @@ int display_months_appts(struct tm *date_in, GtkWidget **day_texts)
    GtkWidget *temp_text;
 
    texts = &day_texts[glob_offset];
-#ifdef ENABLE_GTK2
-   text_buffers = &glob_month_text_buffers[glob_offset];
-#endif
+   text_buffers = &month_day_buffer[glob_offset];
 
    a_list = NULL;
    mask=0;
 
    for (n=0; n<37; n++) {
-#ifdef ENABLE_GTK2
-      temp_text = glob_month_text_views[n];
-#else
-      temp_text = glob_month_texts[n];
-#endif
+      temp_text = month_day[n];
       gstr = gtk_object_get_data(GTK_OBJECT(temp_text), "gstr");
       if (gstr) {
 	 g_string_free(gstr, TRUE);
@@ -395,7 +318,7 @@ int display_months_appts(struct tm *date_in, GtkWidget **day_texts)
 
    /* Set Month name label */
    jp_strftime(str, sizeof(str), "%B %Y", date_in);
-   gtk_label_set_text(GTK_LABEL(glob_month_month_label), str);
+   gtk_label_set_text(GTK_LABEL(month_month_label), str);
 
    memcpy(&date, date_in, sizeof(struct tm));
 
@@ -417,14 +340,7 @@ int display_months_appts(struct tm *date_in, GtkWidget **day_texts)
       date.tm_yday=1;
       mktime(&date);
 
-#ifdef ENABLE_GTK2
       gtk_text_buffer_set_text(GTK_TEXT_BUFFER(text_buffers[n]), "", -1);
-#else
-      gtk_text_set_point(GTK_TEXT(texts[n]),
-			 gtk_text_get_length(GTK_TEXT(texts[n])));
-      gtk_text_backward_delete(GTK_TEXT(texts[n]),
-			       gtk_text_get_length(GTK_TEXT(texts[n])));
-#endif
 
       num_shown = 0;
       for (temp_al = a_list; temp_al; temp_al=temp_al->next) {
@@ -442,11 +358,7 @@ int display_months_appts(struct tm *date_in, GtkWidget **day_texts)
 #endif
 	 if (isApptOnDate(&(temp_al->mappt.appt), &date)) {
 	    if (num_shown) {
-#ifdef ENABLE_GTK2
 	       gtk_text_buffer_insert_at_cursor(GTK_TEXT_BUFFER(text_buffers[n]), "\n", -1);
-#else
-	       gtk_text_insert(GTK_TEXT(texts[n]), NULL, NULL, NULL, "\n", -1);
-#endif
 	       g_string_append(gstr, "\n");
 	    } else {
 	       gstr=g_string_new("");
@@ -470,11 +382,7 @@ int display_months_appts(struct tm *date_in, GtkWidget **day_texts)
 	    /* Append number of anniversary years if enabled & appropriate */
 	    append_anni_years(desc, 35, &date, &temp_al->mappt.appt);
 
-#ifdef ENABLE_GTK2
 	    gtk_text_buffer_insert_at_cursor(GTK_TEXT_BUFFER(text_buffers[n]), desc, -1);
-#else
-	    gtk_text_insert(GTK_TEXT(texts[n]), NULL, NULL, NULL, desc, -1);
-#endif
 	 }
       }
       gtk_object_set_data(GTK_OBJECT(texts[n]), "gstr", gstr);
@@ -489,9 +397,6 @@ void monthview_gui(struct tm *date_in)
    struct tm date;
    GtkWidget *label;
    GtkWidget *button;
-#ifndef ENABLE_GTK2
-   GtkWidget *arrow;
-#endif
    GtkWidget *align;
    GtkWidget *vbox;
    GtkWidget *hbox;
@@ -503,12 +408,12 @@ void monthview_gui(struct tm *date_in)
    char title[200];
    long w, h;
 
-   if (window) {
+   if (monthview_window) {
        /* Delete any existing window to ensure that new window is biased
 	* around currently selected date and so that the new window
 	* contents are updated with any changes on the day view.
 	*/
-       gtk_widget_destroy(window);
+       gtk_widget_destroy(monthview_window);
    }
 
    memcpy(&glob_month_date, date_in, sizeof(struct tm));
@@ -520,20 +425,20 @@ void monthview_gui(struct tm *date_in)
 
    g_snprintf(title, sizeof(title), "%s %s", PN, _("Monthly View"));
 
-   window = gtk_widget_new(GTK_TYPE_WINDOW,
-			   "type", GTK_WINDOW_TOPLEVEL,
-			   "title", title,
-			   NULL);
+   monthview_window = gtk_widget_new(GTK_TYPE_WINDOW,
+	       		                      "type", GTK_WINDOW_TOPLEVEL,
+			                            "title", title,
+			                            NULL);
 
-   gtk_window_set_default_size(GTK_WINDOW(window), w, h);
+   gtk_window_set_default_size(GTK_WINDOW(monthview_window), w, h);
 
-   gtk_container_set_border_width(GTK_CONTAINER(window), 10);
+   gtk_container_set_border_width(GTK_CONTAINER(monthview_window), 10);
 
-   gtk_signal_connect(GTK_OBJECT(window), "destroy",
-                      GTK_SIGNAL_FUNC(cb_destroy), window);
+   gtk_signal_connect(GTK_OBJECT(monthview_window), "destroy",
+                      GTK_SIGNAL_FUNC(cb_destroy), monthview_window);
 
    vbox = gtk_vbox_new(FALSE, 0);
-   gtk_container_add(GTK_CONTAINER(window), vbox);
+   gtk_container_add(GTK_CONTAINER(monthview_window), vbox);
 
    /* This box has the close button and arrows in it */
    align = gtk_alignment_new(0.5, 0.5, 0, 0);
@@ -545,61 +450,39 @@ void monthview_gui(struct tm *date_in)
 
    gtk_container_add(GTK_CONTAINER(align), hbox_temp);
 
-   /*Make a left arrow for going back a week */
-#ifdef ENABLE_GTK2
+   /* Make a left arrow for going back a week */
    button = gtk_button_new_from_stock(GTK_STOCK_GO_BACK);
-#else
-   button = gtk_button_new();
-   arrow = gtk_arrow_new(GTK_ARROW_LEFT, GTK_SHADOW_OUT);
-   gtk_container_add(GTK_CONTAINER(button), arrow);
-#endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_month_move),
 		      GINT_TO_POINTER(-1));
    gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 3);
 
-
-   /* Create a "Close" button */
-#ifdef ENABLE_GTK2
+   /* Close button */
    button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
-#else
-   button = gtk_button_new_with_label(_("Close"));
-#endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(cb_quit), window);
+		      GTK_SIGNAL_FUNC(cb_monthview_quit), monthview_window);
    /* Closing the window via a delete event uses the same cleanup routine */
-   gtk_signal_connect(GTK_OBJECT(window), "delete_event",
-		      GTK_SIGNAL_FUNC(cb_quit), NULL);
+   gtk_signal_connect(GTK_OBJECT(monthview_window), "delete_event",
+		      GTK_SIGNAL_FUNC(cb_monthview_quit), NULL);
    gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 0);
 
-   /* Create a "Print" button */
-#ifdef ENABLE_GTK2
+   /* Print button */
    button = gtk_button_new_from_stock(GTK_STOCK_PRINT);
-#else
-   button = gtk_button_new_with_label(_("Print"));
-#endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(cb_month_print), window);
+		      GTK_SIGNAL_FUNC(cb_month_print), monthview_window);
    gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 0);
 
-   /*Make a right arrow for going forward a week */
-#ifdef ENABLE_GTK2
+   /* Make a right arrow for going forward a week */
    button = gtk_button_new_from_stock(GTK_STOCK_GO_FORWARD);
-#else
-   button = gtk_button_new();
-   arrow = gtk_arrow_new(GTK_ARROW_RIGHT, GTK_SHADOW_OUT);
-   gtk_container_add(GTK_CONTAINER(button), arrow);
-#endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_month_move),
 		      GINT_TO_POINTER(1));
    gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 3);
 
-
    /* Month name label */
    jp_strftime(str, sizeof(str), "%B %Y", &glob_month_date);
-   glob_month_month_label = gtk_label_new(str);
-   gtk_box_pack_start(GTK_BOX(vbox), glob_month_month_label, FALSE, FALSE, 0);
+   month_month_label = gtk_label_new(str);
+   gtk_box_pack_start(GTK_BOX(vbox), month_month_label, FALSE, FALSE, 0);
 
    /* We know this is on a Sunday */
    memset(&date, 0, sizeof(date));
@@ -621,18 +504,12 @@ void monthview_gui(struct tm *date_in)
       add_days_to_date(&date, 1);
    }
 
-   /* glob_month_vbox */
-   glob_month_vbox = vbox;
+   create_month_boxes_texts(vbox);
 
-   create_month_boxes_texts(glob_month_vbox);
-
-   gtk_widget_show_all(window);
+   gtk_widget_show_all(monthview_window);
 
    hide_show_month_boxes();
 
-#ifdef ENABLE_GTK2
-   display_months_appts(&glob_month_date, glob_month_text_views);
-#else
-   display_months_appts(&glob_month_date, glob_month_texts);
-#endif
+   display_months_appts(&glob_month_date, month_day);
 }
+
