@@ -1,4 +1,4 @@
-/* $Id: prefs.c,v 1.79 2008/06/20 04:36:41 rikster5 Exp $ */
+/* $Id: prefs.c,v 1.83 2009/02/14 17:32:31 rousseau Exp $ */
 
 /*******************************************************************************
  * prefs.c
@@ -27,6 +27,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#ifdef HAVE_LANGINFO_H
+#  include <langinfo.h>
+#endif
 
 #include "i18n.h"
 #include "utils.h"
@@ -43,7 +46,7 @@
 #define NUM_PAPER_SIZES 2
 
 /******************************* Global vars **********************************/
-extern int t_fmt_ampm;
+int t_fmt_ampm = TRUE;
 
 /* These are the default settings */
 /* name, usertype, filetype, ivalue, char *svalue, svalue_size; */
@@ -52,7 +55,7 @@ static prefType glob_prefs[NUM_PREFS] = {
      {"time", CHARTYPE, INTTYPE, 0, NULL, 0},
      {"sdate", CHARTYPE, INTTYPE, 0, NULL, 0},
      {"ldate", CHARTYPE, INTTYPE, 0, NULL, 0},
-     {"fdow", CHARTYPE, INTTYPE, 0, NULL, 0},
+     {"xxx_internal1_xxx", CHARTYPE, INTTYPE, 0, NULL, 0},
      {"show_deleted", INTTYPE, INTTYPE, 0, NULL, 0},
      {"show_modified", INTTYPE, INTTYPE, 0, NULL, 0},
      {"todo_hide_completed", INTTYPE, INTTYPE, 0, NULL, 0},
@@ -142,8 +145,11 @@ static prefType glob_prefs[NUM_PREFS] = {
      {"contacts_photo_filename", CHARTYPE, CHARTYPE, 0, NULL, 0},
      {"todo_sort_column", INTTYPE, INTTYPE, 1, NULL, 0},
      {"todo_sort_order", INTTYPE, INTTYPE, 0, NULL, 0},
-     {"addr_sort_order", INTTYPE, INTTYPE, 1, NULL, 0},
+     {"addr_sort_order", INTTYPE, INTTYPE, 0, NULL, 0},
      {"addr_name_col_sz", INTTYPE, INTTYPE, 140, NULL, 0},
+     {"todo_note_pane", INTTYPE, INTTYPE, 200, NULL, 0},
+     {"expense_sort_column", INTTYPE, INTTYPE, 0, NULL, 0},
+     {"expense_sort_order", INTTYPE, INTTYPE, 0, NULL, 0},
 };
 
 struct name_list {
@@ -158,6 +164,11 @@ void pref_init()
 {
    int i;
 
+   /* Determine whether locale supports am/pm time formats */
+#  ifdef HAVE_LANGINFO_H
+      t_fmt_ampm = strcmp(nl_langinfo(T_FMT_AMPM), "");
+#  endif
+
    for (i=0; i<NUM_PREFS; i++) {
       switch (i) {
        case PREF_RCFILE:
