@@ -1,4 +1,4 @@
-/* $Id: todo_gui.c,v 1.144 2008/10/30 15:07:12 rousseau Exp $ */
+/* $Id: todo_gui.c,v 1.152 2009/01/19 22:17:02 rikster5 Exp $ */
 
 /*******************************************************************************
  * todo_gui.c
@@ -84,6 +84,7 @@ static GtkWidget *cancel_record_button;
 static GtkWidget *category_menu1;
 static GtkWidget *category_menu2;
 static GtkWidget *pane;
+static GtkWidget *note_pane;
 
 static ToDoList *glob_todo_list=NULL;
 static ToDoList *export_todo_list=NULL;
@@ -871,15 +872,40 @@ int todo_export(GtkWidget *window)
  */
 
 
-static int find_sorted_cat(int cat)
+/* Find position of category in sorted category array 
+ * via its assigned category number */
+static int find_sort_cat_pos(int cat)
 {
    int i;
-   for (i=0; i< NUM_TODO_CAT_ITEMS; i++) {
+
+   for (i=0; i<NUM_TODO_CAT_ITEMS; i++) {
       if (sort_l[i].cat_num==cat) {
  	 return i;
       }
    }
-   return EXIT_FAILURE;
+
+   return -1;
+}
+
+/* Find a category's position in the category menu.
+ * This is equal to the category number except for the Unfiled category.
+ * The Unfiled category is always in the last position which changes as
+ * the number of categories changes */
+static int find_menu_cat_pos(int cat)
+{
+   int i;
+
+   if (cat != NUM_TODO_CAT_ITEMS-1) {
+      return cat;
+   } else { /* Unfiled category */
+      /* Count how many category entries are filled */
+      for (i=0; i<NUM_TODO_CAT_ITEMS; i++) {
+         if (!sort_l[i].Pcat[0]) {
+            return i;
+         }
+      }
+      return 0;
+   }
 }
 
 void cb_delete_todo(GtkWidget *widget,
@@ -1017,8 +1043,32 @@ static void cb_category(GtkWidget *item, int selection)
    int b;
 
    if ((GTK_CHECK_MENU_ITEM(item))->active) {
-      b=dialog_save_changed_record(pane, record_changed);
-      if (b==DIALOG_SAID_2) {
+      if (todo_category == selection) { return; }
+
+      b=dialog_save_changed_record_with_cancel(pane, record_changed);
+      if (b==DIALOG_SAID_1) { /* Cancel */
+         int index, index2;
+
+         if (todo_category==CATEGORY_ALL) {
+            index  = 0;
+            index2 = 0;
+         } else {
+            index  = find_sort_cat_pos(todo_category);
+            index2 = find_menu_cat_pos(index) + 1;
+            index += 1;
+         }
+
+         if (index<0) {
+            jp_logf(JP_LOG_WARN, _("Category is not legal\n"));
+         } else {
+            gtk_check_menu_item_set_active
+              (GTK_CHECK_MENU_ITEM(todo_cat_menu_item1[index]), TRUE);
+            gtk_option_menu_set_history(GTK_OPTION_MENU(category_menu1), index2);
+         }
+
+	 return;
+      }
+      if (b==DIALOG_SAID_3) { /* Save */
 	 cb_add_new_record(NULL, GINT_TO_POINTER(record_changed));
       }
 
@@ -1029,7 +1079,6 @@ static void cb_category(GtkWidget *item, int selection)
       }
       clist_row_selected = 0;
       jp_logf(JP_LOG_DEBUG, "todo_category = %d\n",todo_category);
-      todo_clear_details();
       todo_update_clist(clist, category_menu1, &glob_todo_list, todo_category, TRUE);
    }
 }
@@ -1094,7 +1143,6 @@ int todo_clear_details()
       update_due_button(due_date_button, NULL);
    }
 
-
    gtk_widget_thaw_child_notify(todo_desc);
    gtk_widget_thaw_child_notify(todo_note);
 
@@ -1103,13 +1151,14 @@ int todo_clear_details()
    } else {
       new_cat = todo_category;
    }
-   sorted_position = find_sorted_cat(new_cat);
+   sorted_position = find_sort_cat_pos(new_cat);
    if (sorted_position<0) {
       jp_logf(JP_LOG_WARN, _("Category is not legal\n"));
    } else {
       gtk_check_menu_item_set_active
 	(GTK_CHECK_MENU_ITEM(todo_cat_menu_item2[sorted_position]), TRUE);
-      gtk_option_menu_set_history(GTK_OPTION_MENU(category_menu2), sorted_position);
+      gtk_option_menu_set_history(GTK_OPTION_MENU(category_menu2), 
+                                  find_menu_cat_pos(sorted_position));
    }
 
    set_new_button_to(CLEAR_FLAG);
@@ -1400,23 +1449,36 @@ static void cb_clist_selection(GtkWidget      *clist,
 {
    struct ToDo *todo;
    MyToDo *mtodo;
-   int i, index, count, b;
-   int sorted_position;
+   int b;
+   int index, sorted_position;
    unsigned int unique_id = 0;
 
    time_t ltime;
    struct tm *now;
 
    if ((record_changed==MODIFY_FLAG) || (record_changed==NEW_FLAG)) {
+      if (clist_row_selected == row) { return; } 
+
       mtodo = gtk_clist_get_row_data(GTK_CLIST(clist), row);
       if (mtodo!=NULL) {
 	 unique_id = mtodo->unique_id;
       }
 
-      b=dialog_save_changed_record(pane, record_changed);
-      if (b==DIALOG_SAID_2) {
+      b=dialog_save_changed_record_with_cancel(pane, record_changed);
+      if (b==DIALOG_SAID_1) { /* Cancel */
+         if (clist_row_selected >=0)
+         {
+            clist_select_row(GTK_CLIST(clist), clist_row_selected, 0);
+         } else {
+            clist_row_selected = 0;
+            clist_select_row(GTK_CLIST(clist), 0, 0);
+         }
+         return;
+      }
+      if (b==DIALOG_SAID_3) { /* Save */
 	 cb_add_new_record(NULL, GINT_TO_POINTER(record_changed));
       }
+
       set_new_button_to(CLEAR_FLAG);
 
       if (unique_id)
@@ -1464,20 +1526,13 @@ static void cb_clist_selection(GtkWidget      *clist,
    gtk_text_buffer_set_text(GTK_TEXT_BUFFER(todo_note_buffer), "", -1);
 
    index = mtodo->attrib & 0x0F;
-   sorted_position = find_sorted_cat(index);
+   sorted_position = find_sort_cat_pos(index);
    if (todo_cat_menu_item2[sorted_position]==NULL) {
       /* Illegal category */
       jp_logf(JP_LOG_DEBUG, "Category is not legal\n");
       index = sorted_position = 0;
-      sorted_position = find_sorted_cat(index);
+      sorted_position = find_sort_cat_pos(index);
    }
-   /* We need to count how many items down in the list this is */
-   for (i=sorted_position, count=0; i>=0; i--) {
-      if (todo_cat_menu_item2[i]) {
-	 count++;
-      }
-   }
-   count--;
 
    if (sorted_position<0) {
       jp_logf(JP_LOG_WARN, _("Category is not legal\n"));
@@ -1485,7 +1540,8 @@ static void cb_clist_selection(GtkWidget      *clist,
       gtk_check_menu_item_set_active
 	(GTK_CHECK_MENU_ITEM(todo_cat_menu_item2[sorted_position]), TRUE);
    }
-   gtk_option_menu_set_history(GTK_OPTION_MENU(category_menu2), count);
+   gtk_option_menu_set_history(GTK_OPTION_MENU(category_menu2), 
+                               find_menu_cat_pos(sorted_position));
 
    if (todo->description) {
       if (todo->description[0]) {
@@ -1864,8 +1920,9 @@ int todo_cycle_cat()
    if (todo_category == CATEGORY_ALL) {
       new_cat = -1;
    } else {
-      new_cat = find_sorted_cat(todo_category);
+      new_cat = find_sort_cat_pos(todo_category);
    }
+
    for (i=0; i<NUM_TODO_CAT_ITEMS; i++) {
       new_cat++;
       if (new_cat >= NUM_TODO_CAT_ITEMS) {
@@ -1877,6 +1934,7 @@ int todo_cycle_cat()
 	 break;
       }
    }
+
    clist_row_selected = 0;
 
    return EXIT_SUCCESS;
@@ -1884,31 +1942,26 @@ int todo_cycle_cat()
 
 int todo_refresh()
 {
-   int index;
+   int index, index2;
 
    if (glob_find_id) {
       todo_category = CATEGORY_ALL;
    }
    if (todo_category==CATEGORY_ALL) {
-      index=0;
+      index  = 0;
+      index2 = 0; 
    } else {
-      index=find_sorted_cat(todo_category)+1;
+      index=find_sort_cat_pos(todo_category);
+      index2 = find_menu_cat_pos(index) + 1;
+      index += 1;
    }
    todo_update_clist(clist, category_menu1, &glob_todo_list, todo_category, TRUE);
    if (index<0) {
       jp_logf(JP_LOG_WARN, _("Category is not legal\n"));
    } else {
-      int i, index2 = 0;
-      for (i=0; i<NUM_TODO_CAT_ITEMS; i++)
-      {
-	 if (todo_cat_menu_item1[i] && (todo_cat_menu_item1[i] != todo_cat_menu_item1[index]))
-	    index2++;
-	 if (todo_cat_menu_item1[i] == todo_cat_menu_item1[index])
-	    break;
-      }
-      gtk_option_menu_set_history(GTK_OPTION_MENU(category_menu1), index2);
       gtk_check_menu_item_set_active
 	(GTK_CHECK_MENU_ITEM(todo_cat_menu_item1[index]), TRUE);
+      gtk_option_menu_set_history(GTK_OPTION_MENU(category_menu1), index2);
    }
    todo_find();
    return EXIT_SUCCESS;
@@ -1925,6 +1978,7 @@ int todo_gui_cleanup()
    free_ToDoList(&glob_todo_list);
    connect_changed_signals(DISCONNECT_SIGNALS);
    set_pref(PREF_TODO_PANE, gtk_paned_get_position(GTK_PANED(pane)), NULL, TRUE);
+   set_pref(PREF_TODO_NOTE_PANE, gtk_paned_get_position(GTK_PANED(note_pane)), NULL, TRUE);
    set_pref(PREF_LAST_TODO_CATEGORY, todo_category, NULL, TRUE);
    set_pref(PREF_TODO_SORT_COLUMN, clist_col_selected, NULL, TRUE);
    set_pref(PREF_TODO_SORT_ORDER, GTK_CLIST(clist)->sort_type, NULL, TRUE);
@@ -1940,6 +1994,7 @@ int todo_gui(GtkWidget *vbox, GtkWidget *hbox)
    GdkBitmap *mask;
    GtkWidget *vbox1, *vbox2;
    GtkWidget *hbox_temp;
+   GtkWidget *vbox_temp;
    GtkWidget *separator;
    GtkWidget *label;
    time_t ltime;
@@ -2155,7 +2210,7 @@ int todo_gui(GtkWidget *vbox, GtkWidget *hbox)
 
 
    /* Priority radio buttons */
-   hbox_temp = gtk_hbox_new (FALSE, 0);
+   hbox_temp = gtk_hbox_new(FALSE, 0);
    gtk_box_pack_start(GTK_BOX(vbox2), hbox_temp, FALSE, FALSE, 0);
 
    label = gtk_label_new(_("Priority: "));
@@ -2207,13 +2262,14 @@ int todo_gui(GtkWidget *vbox, GtkWidget *hbox)
 
    gtk_box_pack_start(GTK_BOX(hbox_temp), category_menu2, TRUE, TRUE, 0);
 
+   note_pane = gtk_vpaned_new();
+   get_pref(PREF_TODO_NOTE_PANE, &ivalue, NULL);
+   gtk_paned_set_position(GTK_PANED(note_pane), ivalue);
+   gtk_box_pack_start(GTK_BOX(vbox2), note_pane, TRUE, TRUE, 0);
 
    /* Description */
    hbox_temp = gtk_hbox_new (FALSE, 0);
-   gtk_box_pack_start(GTK_BOX(vbox2), hbox_temp, FALSE, FALSE, 0);
-
-   hbox_temp = gtk_hbox_new (FALSE, 0);
-   gtk_box_pack_start(GTK_BOX(vbox2), hbox_temp, TRUE, TRUE, 0);
+   gtk_paned_pack1(GTK_PANED(note_pane), hbox_temp, TRUE, FALSE);
 
    todo_desc = gtk_text_view_new();
    todo_desc_buffer = G_OBJECT(gtk_text_view_get_buffer(GTK_TEXT_VIEW(todo_desc)));
@@ -2222,20 +2278,20 @@ int todo_gui(GtkWidget *vbox, GtkWidget *hbox)
 
    scrolled_window = gtk_scrolled_window_new(NULL, NULL);
    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window),
-				  GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
+				  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
    gtk_container_set_border_width(GTK_CONTAINER(scrolled_window), 1);
    gtk_container_add(GTK_CONTAINER(scrolled_window), todo_desc);
    gtk_box_pack_start_defaults(GTK_BOX(hbox_temp), scrolled_window);
 
+
    /* Note */
-   hbox_temp = gtk_hbox_new (FALSE, 0);
-   gtk_box_pack_start(GTK_BOX(vbox2), hbox_temp, FALSE, FALSE, 0);
+   vbox_temp = gtk_vbox_new(FALSE, 0);
+   gtk_paned_pack2(GTK_PANED(note_pane), vbox_temp, TRUE, FALSE);
 
    label = gtk_label_new(_("Note"));
-   gtk_box_pack_start(GTK_BOX(hbox_temp), label, FALSE, FALSE, 0);
-
-   hbox_temp = gtk_hbox_new (FALSE, 0);
-   gtk_box_pack_start(GTK_BOX(vbox2), hbox_temp, TRUE, TRUE, 0);
+   /* Center Note label visually */
+   gtk_misc_set_alignment(GTK_MISC(label), 0.506, 0.5);
+   gtk_box_pack_start(GTK_BOX(vbox_temp), label, FALSE, FALSE, 0);
 
    todo_note = gtk_text_view_new();
    todo_note_buffer = G_OBJECT(gtk_text_view_get_buffer(GTK_TEXT_VIEW(todo_note)));
@@ -2244,13 +2300,10 @@ int todo_gui(GtkWidget *vbox, GtkWidget *hbox)
 
    scrolled_window = gtk_scrolled_window_new(NULL, NULL);
    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window),
-				  GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
+				  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
    gtk_container_set_border_width(GTK_CONTAINER(scrolled_window), 1);
    gtk_container_add(GTK_CONTAINER(scrolled_window), todo_note);
-   gtk_box_pack_start_defaults(GTK_BOX(hbox_temp), scrolled_window);
-
-   gtk_widget_set_usize(GTK_WIDGET(todo_desc), 10, 10);
-   gtk_widget_set_usize(GTK_WIDGET(todo_note), 10, 10);
+   gtk_box_pack_start_defaults(GTK_BOX(vbox_temp), scrolled_window);
 
    /* Capture the TAB key to change focus with it */
    gtk_signal_connect(GTK_OBJECT(todo_desc), "key_press_event",
