@@ -1,4 +1,4 @@
-/* $Id: utils.h,v 1.69 2008/09/21 19:06:47 rikster5 Exp $ */
+/* $Id: utils.h,v 1.71 2009/01/22 02:10:23 rikster5 Exp $ */
 
 /*******************************************************************************
  * utils.h
@@ -317,6 +317,7 @@ int dialog_generic_ok(GtkWidget *widget,
  * changed is MODIFY_FLAG, or NEW_FLAG
  */
 int dialog_save_changed_record(GtkWidget *widget, int changed);
+int dialog_save_changed_record_with_cancel(GtkWidget *widget, int changed);
 
 /* mon 0-11
  * day 1-31
@@ -466,6 +467,7 @@ int find_next_rpt_event(struct Appointment *appt,
 void cb_app_button(GtkWidget *widget, gpointer data);
 
 void call_plugin_gui(int number, int unique_id);
+void plugin_gui_refresh(int unique_id);
 
 /*datebook_gui */
 int datebook_refresh(int first, int do_init);
