@@ -1,4 +1,4 @@
-/* $Id: weekview_gui.c,v 1.38 2008/05/03 02:58:16 judd Exp $ */
+/* $Id: weekview_gui.c,v 1.43 2008/06/19 04:12:08 rikster5 Exp $ */
 
 /*******************************************************************************
  * weekview_gui.c
@@ -20,64 +20,59 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  ******************************************************************************/
 
+/********************************* Includes ***********************************/
 #include "config.h"
-#include "i18n.h"
-#include <gtk/gtk.h>
-#include <string.h>
-#include <ctype.h>
 #include <stdlib.h>
-#include "print.h"
+#include <string.h>
+#include <gtk/gtk.h>
+#include <pi-datebook.h>
+
+#include "i18n.h"
 #include "utils.h"
 #include "prefs.h"
 #include "log.h"
 #include "datebook.h"
-#include <pi-datebook.h>
-
+#include "print.h"
 
+/******************************* Global vars **********************************/
 extern int datebook_category;
 extern int glob_app;
 
-
-static GtkWidget *window=NULL;
-static GtkWidget *glob_dow_labels[8];
-static GtkWidget *glob_week_texts[8];
-#ifdef ENABLE_GTK2
-static GObject   *glob_week_text_buffers[8];
-#endif
+GtkWidget *weekview_window=NULL;
+static GtkWidget *week_day_label[8];
+static GtkWidget *week_day_text[8];
+static GObject   *week_day_text_buffer[8];
 static struct tm glob_week_date;
 
-/* Function prototypes */
+/****************************** Prototypes ************************************/
 int clear_weeks_appts(GtkWidget **day_texts);
 int display_weeks_appts(struct tm *date_in, GtkWidget **day_texts);
 
-
+/****************************** Main Code *************************************/
 static gboolean cb_destroy(GtkWidget *widget)
 {
-   window = NULL;
+   weekview_window = NULL;
    return FALSE;
 }
 
-static void cb_quit(GtkWidget *widget, gpointer data)
+void cb_weekview_quit(GtkWidget *widget, gpointer data)
 {
    int w, h;
 
-   gdk_window_get_size(window->window, &w, &h);
+   gdk_window_get_size(weekview_window->window, &w, &h);
    set_pref(PREF_WEEKVIEW_WIDTH, w, NULL, FALSE);
    set_pref(PREF_WEEKVIEW_HEIGHT, h, NULL, FALSE);
 
-   gtk_widget_destroy(window);
+   gtk_widget_destroy(weekview_window);
 }
 
-/*----------------------------------------------------------------------
- * cb_week_print     This is where week printing is kicked off from
- *----------------------------------------------------------------------*/
-
+/* This is where week printing is kicked off from */
 static void cb_week_print(GtkWidget *widget, gpointer data)
 {
    long paper_size;
 
    jp_logf(JP_LOG_DEBUG, "cb_week_print called\n");
-   if (print_gui(window, DATEBOOK, 2, 0x02) == DIALOG_SAID_PRINT) {
+   if (print_gui(weekview_window, DATEBOOK, 2, 0x02) == DIALOG_SAID_PRINT) {
       get_pref(PREF_PAPER_SIZE, &paper_size, NULL);
       if (paper_size==1) {
 	 print_weeks_appts(&glob_week_date, PAPER_A4);
@@ -87,18 +82,12 @@ static void cb_week_print(GtkWidget *widget, gpointer data)
    }
 }
 
-/*----------------------------------------------------------------------*/
-
 void freeze_weeks_appts()
 {
    int i;
 
    for (i=0; i<8; i++) {
-#ifdef ENABLE_GTK2
-      gtk_widget_freeze_child_notify(glob_week_texts[i]);
-#else
-      gtk_text_freeze(GTK_TEXT(glob_week_texts[i]));
-#endif
+      gtk_widget_freeze_child_notify(week_day_text[i]);
    }
 }
 
@@ -107,11 +96,7 @@ void thaw_weeks_appts()
    int i;
 
    for (i=0; i<8; i++) {
-#ifdef ENABLE_GTK2
-      gtk_widget_thaw_child_notify(glob_week_texts[i]);
-#else
-      gtk_text_thaw(GTK_TEXT(glob_week_texts[i]));
-#endif
+      gtk_widget_thaw_child_notify(week_day_text[i]);
    }
 }
 
@@ -126,8 +111,8 @@ static void cb_week_move(GtkWidget *widget, gpointer data)
 
    freeze_weeks_appts();
 
-   clear_weeks_appts(glob_week_texts);
-   display_weeks_appts(&glob_week_date, glob_week_texts);
+   clear_weeks_appts(week_day_text);
+   display_weeks_appts(&glob_week_date, week_day_text);
 
    thaw_weeks_appts();
 }
@@ -135,19 +120,11 @@ static void cb_week_move(GtkWidget *widget, gpointer data)
 int clear_weeks_appts(GtkWidget **day_texts)
 {
    int i;
-#ifdef ENABLE_GTK2
    GObject   *text_buffer;
-#endif
 
    for (i=0; i<8; i++) {
-#ifdef ENABLE_GTK2
       text_buffer = G_OBJECT(gtk_text_view_get_buffer(GTK_TEXT_VIEW(day_texts[i])));
       gtk_text_buffer_set_text(GTK_TEXT_BUFFER(text_buffer), "", -1);
-#else
-      gtk_text_set_point(GTK_TEXT(day_texts[i]), 0);
-      gtk_text_forward_delete(GTK_TEXT(day_texts[i]),
-			      gtk_text_get_length(GTK_TEXT(day_texts[i])));
-#endif
    }
    return EXIT_SUCCESS;
 }
@@ -180,10 +157,8 @@ int display_weeks_appts(struct tm *date_in, GtkWidget **day_texts)
    long use_db3_tags;
    struct db4_struct db4;
 #endif
-#ifdef ENABLE_GTK2
    GObject *text_buffer;
    char    *markup_str;
-#endif
 
    a_list = NULL;
    text = day_texts;
@@ -195,6 +170,7 @@ int display_weeks_appts(struct tm *date_in, GtkWidget **day_texts)
       svalue = default_date;
    }
 
+   /* Label each day including special markup for TODAY */
    for (i=0; i<8; i++, add_days_to_date(&date, 1)) {
       strftime(short_date, sizeof(short_date), svalue, &date);
       jp_strftime(str_dow, sizeof(str_dow), "%A", &date);
@@ -204,7 +180,6 @@ int display_weeks_appts(struct tm *date_in, GtkWidget **day_texts)
 
       g_snprintf(str, sizeof(str), "%s %s", str_dow, short_date);
 
-#ifdef ENABLE_GTK2
       if (date.tm_mday == now_today)
       {
 	 markup_str = g_markup_printf_escaped("<b>%s</b>", str);
@@ -213,26 +188,19 @@ int display_weeks_appts(struct tm *date_in, GtkWidget **day_texts)
 	 markup_str = g_markup_printf_escaped("%s", str);
          gtk_widget_set_name(GTK_WIDGET(text[i]), "");
       }
-      gtk_label_set_markup(GTK_LABEL(glob_dow_labels[i]), markup_str);
+      gtk_label_set_markup(GTK_LABEL(week_day_label[i]), markup_str);
       g_free(markup_str);
-#else
-      if (date.tm_mday == now_today)
-      {
-	 g_snprintf(str, sizeof(str), "%s%s", str, _(" (TODAY)"));
-      }
-      gtk_label_set_text(GTK_LABEL(glob_dow_labels[i]), str);
-#endif
 
    }
 
    /* Get all of the appointments */
    get_days_appointments2(&a_list, NULL, 2, 2, 2, NULL);
 
-   /* iterate through eight days */
    memcpy(&date, date_in, sizeof(struct tm));
 
-
+   /* Iterate through 8 days */
    for (n=0; n<8; n++, add_days_to_date(&date, 1)) {
+      text_buffer = G_OBJECT(gtk_text_view_get_buffer(GTK_TEXT_VIEW(text[n])));
       for (temp_al = a_list; temp_al; temp_al=temp_al->next) {
 #ifdef ENABLE_DATEBK
 	 get_pref(PREF_USE_DB3, &use_db3_tags, NULL);
@@ -264,12 +232,7 @@ int display_weeks_appts(struct tm *date_in, GtkWidget **day_texts)
 	    append_anni_years(desc, 62, &date, &temp_al->mappt.appt);
 
 	    strcat(desc, "\n");
-#ifdef ENABLE_GTK2
-	    text_buffer = G_OBJECT(gtk_text_view_get_buffer(GTK_TEXT_VIEW(text[n])));
 	    gtk_text_buffer_insert_at_cursor(GTK_TEXT_BUFFER(text_buffer),desc,-1);
-#else
-	    gtk_text_insert(GTK_TEXT(text[n]), NULL, NULL, NULL, desc, -1);
-#endif
 	 }
       }
    }
@@ -300,9 +263,6 @@ static void cb_enter_selected_day(GtkWidget *widget,
 void weekview_gui(struct tm *date_in)
 {
    GtkWidget *button;
-#ifndef ENABLE_GTK2
-   GtkWidget *arrow;
-#endif
    GtkWidget *align;
    GtkWidget *vbox, *hbox;
    GtkWidget *hbox_temp;
@@ -312,12 +272,11 @@ void weekview_gui(struct tm *date_in)
    char title[200];
    long w, h;
 
-   if (window) {
+   if (weekview_window) {
        /* Delete any existing window to ensure that new window is biased
 	* around currently selected date and so that the new window
-	* contents are updated with any changes on the day view.
-	*/
-       gtk_widget_destroy(window);
+	* contents are updated with any changes on the day view. */
+       gtk_widget_destroy(weekview_window);
    }
 
    memcpy(&glob_week_date, date_in, sizeof(struct tm));
@@ -326,20 +285,19 @@ void weekview_gui(struct tm *date_in)
    get_pref(PREF_WEEKVIEW_HEIGHT, &h, NULL);
 
    g_snprintf(title, sizeof(title), "%s %s", PN, _("Weekly View"));
-   window = gtk_widget_new(GTK_TYPE_WINDOW,
-			   "type", GTK_WINDOW_TOPLEVEL,
-			   "title", title,
-			   NULL);
+   weekview_window = gtk_widget_new(GTK_TYPE_WINDOW,
+			            "type", GTK_WINDOW_TOPLEVEL,
+			            "title", title,
+			            NULL);
 
-   gtk_window_set_default_size(GTK_WINDOW(window), w, h);
+   gtk_window_set_default_size(GTK_WINDOW(weekview_window), w, h);
+   gtk_container_set_border_width(GTK_CONTAINER(weekview_window), 10);
 
-   gtk_container_set_border_width(GTK_CONTAINER(window), 10);
-
-   gtk_signal_connect(GTK_OBJECT(window), "destroy",
-                      GTK_SIGNAL_FUNC(cb_destroy), window);
+   gtk_signal_connect(GTK_OBJECT(weekview_window), "destroy",
+                      GTK_SIGNAL_FUNC(cb_destroy), weekview_window);
 
    vbox = gtk_vbox_new(FALSE, 0);
-   gtk_container_add(GTK_CONTAINER(window), vbox);
+   gtk_container_add(GTK_CONTAINER(weekview_window), vbox);
 
    /* This box has the close button and arrows in it */
    align = gtk_alignment_new(0.5, 0.5, 0, 0);
@@ -351,51 +309,31 @@ void weekview_gui(struct tm *date_in)
 
    gtk_container_add(GTK_CONTAINER(align), hbox_temp);
 
-   /*Make a left arrow for going back a week */
-#ifdef ENABLE_GTK2
+   /* Make a left arrow for going back a week */
    button = gtk_button_new_from_stock(GTK_STOCK_GO_BACK);
-#else
-   button = gtk_button_new();
-   arrow = gtk_arrow_new(GTK_ARROW_LEFT, GTK_SHADOW_OUT);
-   gtk_container_add(GTK_CONTAINER(button), arrow);
-#endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_week_move),
 		      GINT_TO_POINTER(-1));
    gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 0);
 
-   /* Create a "Close" button */
-#ifdef ENABLE_GTK2
+   /* Close button */
    button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
-#else
-   button = gtk_button_new_with_label(_("Close"));
-#endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(cb_quit), NULL);
+		      GTK_SIGNAL_FUNC(cb_weekview_quit), NULL);
    /* Closing the window via a delete event uses the same cleanup routine */
-   gtk_signal_connect(GTK_OBJECT(window), "delete_event",
-		      GTK_SIGNAL_FUNC(cb_quit), NULL);
+   gtk_signal_connect(GTK_OBJECT(weekview_window), "delete_event",
+		      GTK_SIGNAL_FUNC(cb_weekview_quit), NULL);
 
    gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 0);
 
-   /* Create a "Print" button */
-#ifdef ENABLE_GTK2
+   /* Print button */
    button = gtk_button_new_from_stock(GTK_STOCK_PRINT);
-#else
-   button = gtk_button_new_with_label(_("Print"));
-#endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(cb_week_print), window);
+		      GTK_SIGNAL_FUNC(cb_week_print), weekview_window);
    gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 0);
 
-   /*Make a right arrow for going forward a week */
-#ifdef ENABLE_GTK2
+   /* Make a right arrow for going forward a week */
    button = gtk_button_new_from_stock(GTK_STOCK_GO_FORWARD);
-#else
-   button = gtk_button_new();
-   arrow = gtk_arrow_new(GTK_ARROW_RIGHT, GTK_SHADOW_OUT);
-   gtk_container_add(GTK_CONTAINER(button), arrow);
-#endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_week_move),
 		      GINT_TO_POINTER(1));
@@ -415,36 +353,34 @@ void weekview_gui(struct tm *date_in)
    /* Get the first day of the week */
    sub_days_from_date(&glob_week_date, (7 - fdow + glob_week_date.tm_wday)%7);
 
+   /* Make 8 boxes, 1 for each day, to hold appt. descriptions */
    for (i=0; i<8; i++) {
-      glob_dow_labels[i] = gtk_label_new("");
-      gtk_misc_set_alignment(GTK_MISC(glob_dow_labels[i]), 0.0, 0.5);
-#ifdef ENABLE_GTK2
-      glob_week_texts[i] = gtk_text_view_new();
-      glob_week_text_buffers[i] = G_OBJECT(gtk_text_view_get_buffer(GTK_TEXT_VIEW(glob_week_texts[i])));
-      gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(glob_week_texts[i]), FALSE);
-      gtk_text_view_set_editable(GTK_TEXT_VIEW(glob_week_texts[i]), FALSE);
-      gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(glob_week_texts[i]), GTK_WRAP_WORD);
-      gtk_container_set_border_width(GTK_CONTAINER(glob_week_texts[i]), 1);
-      gtk_text_buffer_create_tag(GTK_TEXT_BUFFER(glob_week_text_buffers[i]),
+      week_day_label[i] = gtk_label_new("");
+      gtk_misc_set_alignment(GTK_MISC(week_day_label[i]), 0.0, 0.5);
+      week_day_text[i] = gtk_text_view_new();
+      week_day_text_buffer[i] = G_OBJECT(gtk_text_view_get_buffer(GTK_TEXT_VIEW(week_day_text[i])));
+      gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(week_day_text[i]), FALSE);
+      gtk_text_view_set_editable(GTK_TEXT_VIEW(week_day_text[i]), FALSE);
+      gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(week_day_text[i]), GTK_WRAP_WORD);
+      gtk_container_set_border_width(GTK_CONTAINER(week_day_text[i]), 1);
+      gtk_text_buffer_create_tag(GTK_TEXT_BUFFER(week_day_text_buffer[i]),
 				 "gray_background", "background", "gray",
 			         NULL);
-#else
-      glob_week_texts[i] = gtk_text_new(NULL, NULL);
-#endif
-      gtk_widget_set_usize(GTK_WIDGET(glob_week_texts[i]), 10, 10);
-      gtk_signal_connect(GTK_OBJECT(glob_week_texts[i]), "button_release_event",
+      gtk_widget_set_usize(GTK_WIDGET(week_day_text[i]), 10, 10);
+      gtk_signal_connect(GTK_OBJECT(week_day_text[i]), "button_release_event",
 			 GTK_SIGNAL_FUNC(cb_enter_selected_day),
 			 GINT_TO_POINTER(i));
       if (i>3) {
-	 gtk_box_pack_start(GTK_BOX(vbox_right), glob_dow_labels[i], FALSE, FALSE, 0);
-	 gtk_box_pack_start(GTK_BOX(vbox_right), glob_week_texts[i], TRUE, TRUE, 0);
+	 gtk_box_pack_start(GTK_BOX(vbox_right), week_day_label[i], FALSE, FALSE, 0);
+	 gtk_box_pack_start(GTK_BOX(vbox_right), week_day_text[i], TRUE, TRUE, 0);
       } else {
-	 gtk_box_pack_start(GTK_BOX(vbox_left), glob_dow_labels[i], FALSE, FALSE, 0);
-	 gtk_box_pack_start(GTK_BOX(vbox_left), glob_week_texts[i], TRUE, TRUE, 0);
+	 gtk_box_pack_start(GTK_BOX(vbox_left), week_day_label[i], FALSE, FALSE, 0);
+	 gtk_box_pack_start(GTK_BOX(vbox_left), week_day_text[i], TRUE, TRUE, 0);
       }
    }
 
-   display_weeks_appts(&glob_week_date, glob_week_texts);
+   display_weeks_appts(&glob_week_date, week_day_text);
 
-   gtk_widget_show_all(window);
+   gtk_widget_show_all(weekview_window);
 }
+
